.. _updating:
Updating
********


Windows
=======

1. Open the Miniforge Prompt
2. Activate the environment with the following command:

.. code-block:: bash

   conda activate carde-env

3. Update the package with the following command:

.. code-block:: bash

   python3 -m pip install --upgrade carde

Linux
=====

1. Activate the environment with the following command (in a terminal):

.. code-block:: bash

   source carde-env/bin/activate

2. Update the package with the following command:

.. code-block:: bash

   python3 -m pip install --upgrade carde
